@@ -1,12 +1,13 @@
 # Source and destination file names:
-test_source = 'standalone_rst_s5_html.txt'
+test_source = 'standalone_rst_s5_html.rst'
 test_destination = 'standalone_rst_s5_html_2.html'
 
 # Keyword parameters passed to publish_file:
-writer_name = 's5_html'
+writer = 's5_html'
 settings_overrides = {
     'sectsubtitle_xform': True,
     # local copy of default stylesheet:
     'stylesheet_path': 'functional/input/data/html4css1.css',
     'current_slide': 1,
+    'report_level': 3,  # suppress "can't copy themes" warning
     }
